pytilities.types

Package pytilities :: Package types |
[hide private]
[frames] | no frames]

# Source Code for Package pytilities.types

     1  # Copyright (C) 2010 Tim Diels <limyreth@users.sourceforge.net>
     2  #
     3  # This file is part of pytilities.
     4  #
     5  # pytilities is free software: you can redistribute it and/or modify
     6  # it under the terms of the GNU General Public License as published by
     7  # the Free Software Foundation, either version 3 of the License, or
     8  # (at your option) any later version.
     9  #
    10  # pytilities is distributed in the hope that it will be useful,
    11  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    12  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    13  # GNU General Public License for more details.
    14  #
    15  # You should have received a copy of the GNU General Public License
    16  # along with pytilities.  If not, see <http://www.gnu.org/licenses/>.
    17  #
    18
    19  """
    20  Various types
    21
    22  Classes:
    23
    24      - `NumericType`: Represents any numeric type.
    25      - `NumberType`: Represents any number type.
    26      - `SequenceType`: Represents any ordered sequence.
    27      - all types from the standard types package
    28  """
    29
    30  # Normally from name, looks for .name first, in order to change this behaviour
    31  # to just look for the absolute name we first import absolut_import from the
    32  # future
    33  from __future__ import absolute_import as _absolute_import
    34
    35  # now we can get types, rather than .types :/
    36  from types import *
    37
    38  # custom types
    39  from ._numerictypemeta import _NumericTypeMeta
    40  from ._numbertypemeta import _NumberTypeMeta
    41  from ._sequencetypemeta import _SequenceTypeMeta
    42  from .numerictype import NumericType
    43  from .numbertype import NumberType
    44  from .sequencetype import SequenceType
    45
    46  __docformat__ = 'reStructuredText'
    47